@@ -205,7 +205,7 @@ class Cursor:
         elif isinstance(obj, ListType) or isinstance(obj, TupleType):
             converted_obj = []
             for item in obj:
-                if type(item) is UnicodeType:
+                if isinstance(item, UnicodeType):
                     converted_obj.append(item.encode(*self.con.encoding))
                 else:
                     converted_obj.append(item)
@@ -213,7 +213,7 @@ class Cursor:
         elif isinstance(obj, DictType):
             converted_obj = {}
             for k, v in obj.items():
-                if type(v) is UnicodeType:
+                if isinstance(v, UnicodeType):
                     converted_obj[k] = v.encode(*self.con.encoding)
                 else:
                     converted_obj[k] = v
@@ -221,7 +221,7 @@ class Cursor:
         elif isinstance(obj, PgResultSet):
             obj = copy.copy(obj)
             for k, v in obj.items():
-                if type(v) is UnicodeType:
+                if isinstance(v, UnicodeType):
                     obj[k] = v.encode(*self.con.encoding)
             return obj
         else:
@@ -233,7 +233,7 @@ class Cursor:
         if self.con.autocommit:
             pass
         else:
-            if not(self.con.inTransaction or SQL[:6].upper() == "SELECT"):
+            if not(self.con.inTransaction or SQL[:6].upper() in ("SELECT","VACUUM","DETACH")):
                 self.con._begin()
                 self.con.inTransaction = 1
 
